==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/ClinitElimTransformer.h <==
// public class soot.jimple.toolkits.callgraph.ClinitElimTransformer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 9c916c29a8a7bad2 soot_jimple_toolkits_callgraph_ClinitElimTransformer

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_ClinitElimTransformer_H_
#define _JC_soot_jimple_toolkits_callgraph_ClinitElimTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_refs	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$refs	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$nonrefs	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$object	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vmethods	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtable	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtype	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$method_info$internalTransform$9abd4924859b68a3;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vmethods	soot_jimple_toolkits_callgraph_ClinitElimTransformer;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$refs {
    _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_refs	soot_jimple_toolkits_callgraph_ClinitElimTransformer;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_nonrefs	soot_jimple_toolkits_callgraph_ClinitElimTransformer;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$object {
	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtype _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_ClinitElimTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_ClinitElimTransformer_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/ClinitElimTransformer.h <==
// public class soot.jimple.toolkits.callgraph.ClinitElimTransformer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 9c916c29a8a7bad2 soot_jimple_toolkits_callgraph_ClinitElimTransformer

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_ClinitElimTransformer_H_
#define _JC_soot_jimple_toolkits_callgraph_ClinitElimTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_refs	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$refs	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$nonrefs	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$object	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vmethods	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtable	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtype	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$method_info$internalTransform$9abd4924859b68a3;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vmethods	soot_jimple_toolkits_callgraph_ClinitElimTransformer;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$refs {
    _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_refs	soot_jimple_toolkits_callgraph_ClinitElimTransformer;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$sub_nonrefs	soot_jimple_toolkits_callgraph_ClinitElimTransformer;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$object {
	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$vtype _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_ClinitElimTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_ClinitElimTransformer$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_ClinitElimTransformer_H_ */
